#include "bugagent.h"

#include "branchitem.h"
#include "mainwindow.h"
#include "vymmodel.h"

extern Main *mainWindow;

BugAgent::BugAgent (BranchItem *bi,const QString &bug)
{
	if (!bi) 
	{
		qWarning ("Const BugAgent: bi==NULL");
		return;
	}
	branchID=bi->getID();
	modelID=bi->getModel()->getID();
	bugID=bug;

	script="test/vym-bug.pl";

	p=new Process;

	connect (p, SIGNAL (finished(int,QProcess::ExitStatus) ), 
		this, SLOT (processFinished(int,QProcess::ExitStatus) ));

	p->start (script,QStringList()<<bugID);
	if (!p->waitForStarted())
	{
		qWarning()<<"BugAgent::getBugzillaData couldn't start "<<script;
		return;
	}	
}

BugAgent::~BugAgent ()
{
	delete p;
}

void BugAgent::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
{
	if (exitStatus==QProcess::NormalExit)
	{
		VymModel *model=mainWindow->getModel (modelID);
		if (model)
		{
			BranchItem *bi=(BranchItem*)(model->findID (branchID));		
			if (bi)
			{
				QString oldsel=model->getSelectString ();
				model->select (bi);

				// Now do needed changes:

				QString result=p->getStdout();
				while (result.endsWith("\n")) result.chop(1); 
				//qWarning() << QString(result);
				QString err=p->getErrout();
				if (!err.isEmpty())
				{
					qWarning() << "VM::BugAgent Error:\n";
					qWarning() <<err;
				}
				else if (!result.isEmpty())
				{
					QString heading,cdate,mdate,state,whiteboard;
					QRegExp re("short_desc:(.*)\n");
					re.setMinimal(true);
					if (re.indexIn (result) !=-1) heading=re.cap(1);

					re.setPattern ("creation_ts:(.*)\n");
					if (re.indexIn (result) !=-1) cdate=re.cap(1);

					re.setPattern ("delta_ts:(.*)\n");
					if (re.indexIn (result) !=-1) mdate=re.cap(1);

					re.setPattern ("bug_status:(.*)\n");
					if (re.indexIn (result) !=-1) state=re.cap(1);

					re.setPattern ("status_whiteboard:(.*)\n");
					if (re.indexIn (result) !=-1) whiteboard=re.cap(1);

					model->setHeading (bugID + " - " + heading);
					qDebug() << "VM: heading="<<heading;
					qDebug() << "VM:   cdate="<<cdate;
					qDebug() << "VM:   mdate="<<mdate;
					qDebug() << "VM:   state="<<state;
					qDebug() << "VM:  wboard="<<whiteboard;
					
					//qDebug() <<"VM::getBugzillaData  "<<script<<" returned:\n";
					//qDebug() <<QString(result);
				} else	
					qWarning() << "VM::getBugzillaData "<<script<<"  returned nothing\n";



				// Changes finished
				model->select (oldsel);
			} else
				qWarning ()<<"BugAgent: Found model, but not branch #"<<branchID;
		} else
			qWarning ()<<"BugAgent: Couldn't find model #"<<modelID;
	} else		
		qWarning()<< "BugAgent: Process finished with exitCode="<<exitCode;
	delete (this);
}



